==> dokuwiki-2013.05.10.tgz: dokuwiki/inc/lang/af/lang.php <==
<?php
/**
 * af language file
 *
 * This file was initially built by fetching translations from other
 * Wiki projects. See the @url lines below. Additional translations
 * and fixes where done for DokuWiki by the people mentioned in the
 * lines starting with @author
 *
 * @url http://svn.wikimedia.org/viewvc/mediawiki/trunk/phase3/languages/messages/MessagesAf.php?view=co
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['btn_edit']              = 'Wysig hierdie bladsy';
$lang['btn_source']            = 'Bekyk bronteks';
$lang['btn_search']            = 'Soek';
$lang['btn_preview']           = 'Voorskou';
$lang['btn_revs']              = 'geskiedenis';
$lang['btn_recent']            = 'Onlangse wysigings';
$lang['btn_cancel']            = 'Kanselleer';
$lang['btn_secedit']           = 'Wysig';
$lang['btn_login']             = 'Teken in';
$lang['btn_logout']            = 'Teken uit';
$lang['btn_back']              = 'Terug';
$lang['btn_backlink']          = 'Wat skakel hierheen';
$lang['btn_subscribe']         = 'Hou bladsy dop';
$lang['btn_unsubscribe']       = 'Verwyder van bladsy  dophoulys';
$lang['btn_register']          = 'Skep gerus \'n rekening';
$lang['loggedinas']            = 'Ingeteken as';
$lang['user']                  = 'Gebruikernaam';
$lang['pass']                  = 'Wagwoord';
$lang['newpass']               = 'Nuive wagwoord';
$lang['oldpass']               = 'Ou wagwoord';
$lang['passchk']               = 'Herhaal wagwoord';
$lang['remember']              = 'Onthou my wagwoord oor sessies';
$lang['fullname']              = 'Regte naam';
$lang['email']                 = 'E-pos';
$lang['badlogin']              = 'Intekenfout';
$lang['minoredit']             = 'Klein wysiging';
$lang['reguexists']            = 'Die gebruikersnaam wat jy gebruik het, is alreeds gebruik. Kies asseblief \'n ander gebruikersnaam.';
$lang['regsuccess2']           = 'Rekening geskep';
$lang['regbadpass']            = 'Die ingetikte wagwoorde is nie dieselfde nie.';
$lang['regpwmail']             = 'Jo DokuWiki wagwoord';
$lang['profnoempty']           = 'Jy moet \'n name en a e-posadres in sit';
$lang['resendpwdmissing']      = 'Jammer, jy moet ales in fil';
$lang['resendpwdconfirm']      = '\'n Bevestigingpos is gestuur na die gekose e-posadres.';
$lang['resendpwdsuccess']      = 'Jou nuive wagwoord was deur e-pos gesteur';
$lang['fileupload']            = 'Laai lêer';
$lang['uploadsucc']            = 'Laai suksesvol';
$lang['uploadfail']            = 'Laai fout';
$lang['js']['hidedetails']     = 'Steek weg';
$lang['mediaroot']             = 'root';
$lang['toc']                   = 'Inhoud';
$lang['current']               = 'huidige';
$lang['line']                  = 'Streak';
$lang['youarehere']            = 'Jy is hier';
$lang['by']                    = 'by';
$lang['restored']              = 'Het terug gegaan na vroeëre weergawe (%s)';
$lang['summary']               = 'Voorskou';
$lang['qb_bold']               = 'Vetdruk';
$lang['qb_italic']             = 'Skuinsdruk';
$lang['qb_link']               = 'Interne skakel';
$lang['qb_extlink']            = 'Eksterne skakel';
$lang['qb_hr']                 = 'Horisontale streep';
$lang['qb_sig']                = 'Handtekening met datum';
$lang['admin_register']        = 'Skep gerus \'n rekening';
$lang['img_backto']            = 'Terug na';
$lang['img_date']              = 'Datem';
$lang['img_camera']            = 'Camera';
$lang['i_wikiname']            = 'Wiki Naam';
$lang['i_funcna']              = 'PHP funksie <code>%s</code> is nie beskibaar nie. Miskien is dit af gehaal.';

==> dokuwiki-2023.04.04p0.tgz: dokuwiki/inc/lang/af/lang.php <==
<?php
/**
 * af language file
 *
 * This file was initially built by fetching translations from other
 * Wiki projects. See the @url lines below. Additional translations
 * and fixes where done for DokuWiki by the people mentioned in the
 * lines starting with @author
 *
 * @url http://svn.wikimedia.org/viewvc/mediawiki/trunk/phase3/languages/messages/MessagesAf.php?view=co
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['btn_edit']              = 'Wysig hierdie bladsy';
$lang['btn_source']            = 'Bekyk bronteks';
$lang['btn_search']            = 'Soek';
$lang['btn_preview']           = 'Voorskou';
$lang['btn_revs']              = 'geskiedenis';
$lang['btn_recent']            = 'Onlangse wysigings';
$lang['btn_cancel']            = 'Kanselleer';
$lang['btn_secedit']           = 'Wysig';
$lang['btn_login']             = 'Teken in';
$lang['btn_logout']            = 'Teken uit';
$lang['btn_back']              = 'Terug';
$lang['btn_backlink']          = 'Wat skakel hierheen';
$lang['btn_subscribe']         = 'Hou bladsy dop';
$lang['btn_register']          = 'Skep gerus \'n rekening';
$lang['loggedinas']            = 'Ingeteken as:';
$lang['user']                  = 'Gebruikernaam';
$lang['pass']                  = 'Wagwoord';
$lang['newpass']               = 'Nuive wagwoord';
$lang['oldpass']               = 'Ou wagwoord';
$lang['passchk']               = 'Herhaal wagwoord';
$lang['remember']              = 'Onthou my wagwoord oor sessies';
$lang['fullname']              = 'Regte naam';
$lang['email']                 = 'E-pos';
$lang['badlogin']              = 'Intekenfout';
$lang['minoredit']             = 'Klein wysiging';
$lang['reguexists']            = 'Die gebruikersnaam wat jy gebruik het, is alreeds gebruik. Kies asseblief \'n ander gebruikersnaam.';
$lang['regsuccess2']           = 'Rekening geskep';
$lang['regbadpass']            = 'Die ingetikte wagwoorde is nie dieselfde nie.';
$lang['regpwmail']             = 'Jo DokuWiki wagwoord';
$lang['profnoempty']           = 'Jy moet \'n name en a e-posadres in sit';
$lang['resendpwdmissing']      = 'Jammer, jy moet ales in fil';
$lang['resendpwdconfirm']      = '\'n Bevestigingpos is gestuur na die gekose e-posadres.';
$lang['resendpwdsuccess']      = 'Jou nuive wagwoord was deur e-pos gesteur';
$lang['uploadsucc']            = 'Laai suksesvol';
$lang['uploadfail']            = 'Laai fout';
$lang['js']['hidedetails']     = 'Steek weg';
$lang['mediaroot']             = 'root';
$lang['toc']                   = 'Inhoud';
$lang['current']               = 'huidige';
$lang['line']                  = 'Streak';
$lang['youarehere']            = 'Jy is hier:';
$lang['by']                    = 'by';
$lang['restored']              = 'Het terug gegaan na vroeëre weergawe (%s)';
$lang['summary']               = 'Voorskou';
$lang['qb_bold']               = 'Vetdruk';
$lang['qb_italic']             = 'Skuinsdruk';
$lang['qb_link']               = 'Interne skakel';
$lang['qb_extlink']            = 'Eksterne skakel';
$lang['qb_hr']                 = 'Horisontale streep';
$lang['qb_sig']                = 'Handtekening met datum';
$lang['btn_img_backto']        = 'Terug na %s';
$lang['img_date']              = 'Datem:';
$lang['img_camera']            = 'Camera:';
$lang['i_wikiname']            = 'Wiki Naam';
$lang['i_funcna']              = 'PHP funksie <code>%s</code> is nie beskibaar nie. Miskien is dit af gehaal.';
